@@ -3,11 +3,56 @@ Currently, this package is experimental and may change in the future.
 """
 from __future__ import absolute_import
 import sys
+import importlib.util
+
+from pathlib import Path
+
+from importlib.abc import MetaPathFinder
+from importlib.machinery import ExtensionFileLoader
+
+LOADING_STACK = []
+
+def find_lib_path(paths, vtk_module_name):
+    for ext in [".pyd", ".so"]:
+        for base_path in paths:
+            for f in Path(base_path).glob(f"{vtk_module_name}.*{ext}"):
+                return str(f.resolve())
+
+
+class VTKMetaHook(MetaPathFinder):
+    """Attach a custom  loaded for vtk native library loading to defer loading of pure python dependencies"""
+    def find_spec(self, fullname, path, target=None):
+        if fullname.startswith("vtkmodules.vtk"):
+            vtk_module_name = fullname.split(".")[1]
+            module_path = find_lib_path(path, vtk_module_name)
+            if module_path is None:
+                return None
+
+            LOADING_STACK.append(fullname)
+            return importlib.util.spec_from_file_location(fullname, module_path, loader=VTKLoader(fullname, module_path))
+
+        return None
+
+
+class VTKLoader(ExtensionFileLoader):
+    """Flush any pending dependency load once initialize() phase is done"""
+    def exec_module(self, module):
+        super().exec_module(module)
+
+        # Process pending dependencies only if the module match the first load request
+        if len(LOADING_STACK) and LOADING_STACK[0] == module.__name__:
+            LOADING_STACK.clear()
+            on_vtk_module_init_completed()
+
+
+
+# Register our hook for vtk library loader
+sys.meta_path.insert(0, VTKMetaHook())
 
 
 def _windows_dll_path():
     import os
-    _vtk_python_path = 'lib/python3.12/site-packages/vtkmodules'
+    _vtk_python_path = 'lib/python3.13/site-packages/vtkmodules'
     _vtk_dll_path = 'bin'
     # Compute the DLL path based on the location of the file and traversing up
     # the installation prefix to append the DLL path.
@@ -58,7 +103,7 @@ def _load_vtkmodules_static():
 #------------------------------------------------------------------------------
 # list the contents
 __all__ = [
-    'vtkCommonCore',
+        'vtkCommonCore',
     'vtkWebCore',
     'vtkCommonMath',
     'vtkCommonTransforms',
@@ -89,6 +134,8 @@ __all__ = [
     'vtkViewsInfovis',
     'vtkCommonComputationalGeometry',
     'vtkCommonSystem',
+    'vtkFiltersCellGrid',
+    'vtkIOCellGrid',
     'vtkIOLegacy',
     'vtkDomainsChemistry',
     'vtkRenderingContextOpenGL2',
@@ -96,6 +143,7 @@ __all__ = [
     'vtkImagingMath',
     'vtkRenderingVolumeOpenGL2',
     'vtkViewsContext2D',
+    'vtkImagingColor',
     'vtkTestingRendering',
     'vtkInteractionImage',
     'vtkRenderingRayTracing',
@@ -108,6 +156,7 @@ __all__ = [
     'vtkRenderingLICOpenGL2',
     'vtkRenderingParallelLIC',
     'vtkRenderingParallel',
+    'vtkRenderingVRModels',
     'vtkRenderingVR',
     'vtkRenderingOpenXR',
     'vtkRenderingOpenVR',
@@ -119,8 +168,8 @@ __all__ = [
     'vtkIOFFMPEG',
     'vtkRenderingFFMPEGOpenGL2',
     'vtkRenderingExternal',
-    'vtkFiltersCellGrid',
     'vtkRenderingCellGrid',
+    'vtkRenderingAnari',
     'vtkParallelMPI4Py',
     'vtkIOXdmf2',
     'vtkIOVeraOut',
@@ -155,28 +204,32 @@ __all__ = [
     'vtkIOMPIImage',
     'vtkIOMINC',
     'vtkIOLAS',
-    'vtkIOInfovis',
     'vtkIOImport',
     'vtkIOIOSS',
+    'vtkIOHDF',
     'vtkIOH5part',
     'vtkIOH5Rage',
     'vtkIOGeoJSON',
     'vtkIOFides',
     'vtkIOFLUENTCFF',
+    'vtkIOFDS',
+    'vtkIOInfovis',
     'vtkIOExportPDF',
     'vtkRenderingGL2PSOpenGL2',
     'vtkIOExportGL2PS',
+    'vtkIOEngys',
     'vtkIOEnSight',
+    'vtkIOERF',
     'vtkIOCityGML',
     'vtkIOChemistry',
     'vtkIOCesium3DTiles',
-    'vtkIOCellGrid',
     'vtkIOCONVERGECFD',
-    'vtkIOHDF',
     'vtkIOCGNSReader',
     'vtkIOAsynchronous',
+    'vtkIOAlembic',
     'vtkIOAMR',
     'vtkIOADIOS2',
+    'vtkInfovisLayout',
     'vtkInfovisBoostGraphAlgorithms',
     'vtkImagingStencil',
     'vtkImagingStatistics',
@@ -184,22 +237,16 @@ __all__ = [
     'vtkImagingOpenGL2',
     'vtkImagingMorphological',
     'vtkImagingFourier',
-    'vtkIOGDAL',
-    'vtkGeovisGDAL',
-    'vtkCommonColor',
-    'vtkImagingSources',
-    'vtkInfovisCore',
-    'vtkGeovisCore',
-    'vtkInfovisLayout',
     'vtkRenderingAnnotation',
     'vtkImagingHybrid',
-    'vtkImagingColor',
+    'vtkIOGDAL',
+    'vtkGeovisGDAL',
+    'vtkGeovisCore',
     'vtkFiltersTopology',
     'vtkFiltersTensor',
     'vtkFiltersSelection',
     'vtkFiltersSMP',
     'vtkFiltersReebGraph',
-    'vtkFiltersReduction',
     'vtkFiltersPython',
     'vtkFiltersProgrammable',
     'vtkFiltersModeling',
@@ -220,6 +267,7 @@ __all__ = [
     'vtkFiltersFlowPaths',
     'vtkFiltersParallelFlowPaths',
     'vtkFiltersParallelDIY2',
+    'vtkFiltersTemporal',
     'vtkFiltersGeometryPreview',
     'vtkFiltersGeneric',
     'vtkFiltersAMR',
@@ -229,9 +277,13 @@ __all__ = [
     'vtkCommonPython',
     'vtkCommonArchive',
     'vtkChartsCore',
+    'vtkCommonColor',
+    'vtkImagingSources',
+    'vtkInfovisCore',
     'vtkAcceleratorsVTKmCore',
     'vtkAcceleratorsVTKmDataModel',
     'vtkAcceleratorsVTKmFilters',
+    'vtkFiltersReduction',
     'all',
     'gtk',
     'numpy_interface',
@@ -240,8 +292,48 @@ __all__ = [
     'tk',
     'util',
     'wx',
-]
 
+]
 #------------------------------------------------------------------------------
 # get the version
-__version__ = "9.3.1"
+__version__ = "9.4.1"
+
+#------------------------------------------------------------------------------
+# describe import dependencies to properly define Python @override
+MODULE_MAPPER = {
+    "vtkCommonDataModel": [
+        "vtkmodules.util.data_model",
+    ],
+    "vtkCommonExecutionModel": [
+        "vtkmodules.util.execution_model",
+    ],
+}
+LOADED_MODULES = set()
+PENDING_LOADED_MODULES = set()
+
+def register_vtk_module_dependencies(vtk_module_name, *import_names):
+    """Method to call for registering external override on vtkmodule load"""
+    MODULE_MAPPER.setdefault(vtk_module_name, []).extend(import_names)
+
+    # If already loaded let's make sure we import it now
+    if vtk_module_name in LOADED_MODULES:
+        for import_name in import_names:
+            importlib.import_module(import_name)
+
+
+def on_vtk_module_init(module_name):
+    """Automatically called by vtkmodule when they are loaded"""
+    if module_name in LOADED_MODULES:
+        return
+
+    PENDING_LOADED_MODULES.add(module_name)
+
+
+def on_vtk_module_init_completed():
+    pending = list(PENDING_LOADED_MODULES)
+    PENDING_LOADED_MODULES.clear()
+
+    for module_name in pending:
+        LOADED_MODULES.add(module_name)
+        for import_name in MODULE_MAPPER.get(module_name, []):
+            importlib.import_module(import_name)
